Lrabbit_spider
=====

Lrabbit_spider is small scrapy



Installing
----------

    $ pip install -U lrabbit_scrapy

A Simple Example
----------------

    $ pip install -U lrabbit_scrapy
    $ python -m lrabbit_scrapy newscrapy blog_scrapy
    $ cd blog_scrapy
    $ python blog_scrapy.py

Links
-----

- author: https://www.lrabbit.life/

